@@ -1,5 +1,4 @@
 import os.path
-
 from .base_producer import BlockingProducer
 from ..models import ArtifactUploadRequest, ArtifactMetadata
 from ..models import QueueMessage
@@ -10,6 +9,8 @@ import os
 from ubai_client.apis import ArtifactApi
 from ubai_client.models import ArtifactInput
 from otel_extensions import instrumented
+from typing import Optional
+from utf_queue_client import DISABLE_SSL_VERIFICATION_DEFAULT
 
 __all__ = [
     "UbaiArtifactUploadRequestProducer",
@@ -90,8 +91,18 @@ class UbaiArtifactUploadRequestProducer:
         base64_content: str,
         metadata: dict,
         validate_metadata: bool = True,
+        verify_ssl: Optional[bool] = None,
     ):
+        if verify_ssl is None:
+            verify_ssl = not (
+                os.environ.get(
+                    "DISABLE_SSL_VERIFICATION", DISABLE_SSL_VERIFICATION_DEFAULT
+                )
+                == "true"
+            )
         artifact_api = ArtifactApi()
+        if not verify_ssl:
+            artifact_api.api_client.configuration.verify_ssl = False
         artifact_input = ArtifactInput(
             name=name,
             extension=extension,
