@@ -1,12 +1,13 @@
 import click
 from typing import Iterable, Tuple, Optional
 from ubai_client.apis import SearchApi
+from utf_queue_client import DISABLE_SSL_VERIFICATION_DEFAULT
 from ubai_client.models import ArtifactStorage
-from time import sleep
 from utf_queue_client.scripts import setup_telemetry
 from otel_extensions import instrumented
 from retry import retry
 from opentelemetry import trace
+import os
 
 
 @click.command()
@@ -55,6 +56,11 @@ def cli(
 @instrumented
 def find_all_artifacts(search_opts: ArtifactStorage):
     search_api = SearchApi()
+    if (
+        os.environ.get("DISABLE_SSL_VERIFICATION", DISABLE_SSL_VERIFICATION_DEFAULT)
+        == "true"
+    ):
+        search_api.api_client.configuration.verify_ssl = False
     span = trace.get_current_span()
     span.set_attribute("artifact.name", search_opts.get("name") or "")
     span.set_attribute("artifact.extension", search_opts.get("extension") or "")
